@@ -3,7 +3,7 @@ use warnings;
 package Graphics::Raylib;
 
 # ABSTRACT: Perlish wrapper for Raylib videogame library
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 use Carp;
 use Graphics::Raylib::XS qw(:all);
@@ -21,7 +21,7 @@ Graphics::Raylib - Perlish wrapper for Raylib videogame library
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -186,8 +186,6 @@ sub DESTROY {
 
     my $HZ = 120;
     my $SIZE = 160;
-    my $MUTATION_CHANCE = 0.000;
-
     ###########
 
     my $CELL_SIZE = 3;
@@ -225,13 +223,13 @@ sub DESTROY {
 
     my $rainbow = Graphics::Raylib::Color::rainbow(colors => 240);
 
-    $g->clear(BLACK);
-
     while (!$g->exiting) {
         $bitmap->matrix = unpdl($gen);
         $bitmap->color = $rainbow->();
         $text->text = "Generation " . ($i++);
 
+        $g->clear(BLACK);
+
         Graphics::Raylib::draw {
             $bitmap->draw;
             $text->draw;
@@ -246,9 +244,6 @@ sub DESTROY {
         #  next gen are live cells with three neighbours or any with two
         my $next = $gen & ($neighbourhood == 4) | ($neighbourhood == 3);
 
-        # mutation
-        $next |= $neighbourhood == 2 if rand(1) < $MUTATION_CHANCE;
-
         # procreate
         $gen = $next;
     }
